OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Contrasinal incorrecto",
    "No user supplied" : "Non subministrado polo usuario",
    "Authentication error" : "Produciuse un erro de autenticación",
    "Wrong admin recovery password. Please check the password and try again." : "Contrasinal de recuperación do administrador incorrecto. Comprobe o contrasinal e ténteo de novo.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "A infraestrutura non admite o cambio de contrasinal, mais a chave de cifrado do usuario foi actualizada correctamente.",
    "Unable to change password" : "Non é posíbel cambiar o contrasinal",
    "Couldn't send reset email. Please contact your administrator." : "Non foi posíbel enviar o correo do restabelecemento. Póñase en contacto co administrador.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "instalando e actualizando aplicacións a través da tenda de aplicacións ou da nube federada compartida",
    "Federated Cloud Sharing" : "Nube federada compartida",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL está utilizando unha versión obsoleta %s (%s). Actualice o seu sistema operativo, caso contrario características como %s non funcionarán de xeito fiábel.",
    "A problem occurred, please check your log files (Error: %s)" : "Ocorreu un problema revise os ficheiros de rexistro (Erro: %s)",
    "Migration Completed" : "Completouse a migración",
    "Group already exists." : "Xa existe o grupo.",
    "Unable to add group." : "Non é posíbel engadir o grupo.",
    "Unable to delete group." : "Non é posíbel eliminar o grupo.",
    "log-level out of allowed range" : "o nivel do rexistro está fora do intervalo admitido",
    "Saved" : "Gardado",
    "test email settings" : "correo de proba dos axustes",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ocorreu un problema ao enviar o correo. Revise a súa configuración. (Erro: %s)",
    "Email sent" : "Correo enviado",
    "You need to set your user email before being able to send test emails." : "É necesario configurar o correo do usuario antes de poder enviar mensaxes de correo de proba.",
    "Invalid mail address" : "Enderezo de correo incorrecto",
    "A user with that name already exists." : "Xa existe un usuario con ese nome.",
    "Unable to create user." : "Non é posíbel crear o usuario.",
    "Your %s account was created" : "Foi creada a conta %s",
    "Unable to delete user." : "Non é posíbel eliminar o usuario.",
    "Forbidden" : "Prohibido",
    "Invalid user" : "Usuario incorrecto",
    "Unable to change mail address" : "Non é posíbel cambiar o enderezo de correo.",
    "Your full name has been changed." : "O seu nome completo foi cambiado",
    "Unable to change full name" : "Non é posíbel cambiar o nome completo",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "__language_name__" : "Galego",
    "Language changed" : "O idioma cambiou",
    "Invalid request" : "Petición incorrecta",
    "Admins can't remove themself from the admin group" : "Os administradores non poden eliminarse a si mesmos do grupo admin",
    "Unknown user" : "Usuario descoñecido",
    "Couldn't remove app." : "Non foi posíbel retirar a aplicación.",
    "Official" : "Oficial",
    "Approved" : "Aprobado",
    "All" : "Todo",
    "Enabled" : "Activado",
    "Not enabled" : "Non activado",
    "No apps found for your version" : "Non se atoparon aplicativos para esta versión",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "As aplicacións oficiais son desenvolvidas pola comunidade dentro de ownCloud. Ofrecen una funcionalidade central para ownCloud e están preparadas para o seu uso en produción.",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "As aplicacións aprobadas son desenvolvidas por desenvolvedores de confianza e pasaron un control de seguridade superficial. Mantéñense activamente nun repositorio de código aberto e os seus mantedores consideran que son estábeis para uso casual normal.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "A esta aplicación non se lle fixeron comprobacións de seguridade, ademais é nova ou coñecida por ser inestábel. Instálea baixo a súa responsabilidade.",
    "Please wait...." : "Agarde...",
    "Error while disabling app" : "Produciuse un erro ao desactivar a aplicación",
    "Disable" : "Desactivar",
    "Enable" : "Activar",
    "Error while enabling app" : "Produciuse un erro ao activar a aplicación",
    "Updating...." : "Actualizando...",
    "Error while updating app" : "Produciuse un erro mentres actualizaba a aplicación",
    "Updated" : "Actualizado",
    "Uninstalling ...." : "Desinstalando ...",
    "Error while uninstalling app" : "Produciuse un erro ao desinstalar o aplicatvo",
    "Uninstall" : "Desinstalar",
    "Experimental" : "Experimental",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Confirma que quere engadir «{domain}» como dominio de confianza?",
    "Add trusted domain" : "Engadir dominio de confianza",
    "Migration in progress. Please wait until the migration is finished" : "A migración está en proceso. Agarde a que remate.",
    "Migration started …" : "Iniciada a migración ...",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Produciuse un erro. Envíe un certificado PEM codificado en ASCII.",
    "Valid until {date}" : "Válido ata {date}",
    "Delete" : "Eliminar",
    "Sending..." : "Enviando...",
    "An error occurred: {message}" : "Produciuse un erro: {message}",
    "Select a profile picture" : "Seleccione unha imaxe para o perfil",
    "Very weak password" : "Contrasinal moi feble",
    "Weak password" : "Contrasinal feble",
    "So-so password" : "Contrasinal non moi aló",
    "Good password" : "Bo contrasinal",
    "Strong password" : "Contrasinal forte",
    "Groups" : "Grupos",
    "Unable to delete {objName}" : "Non é posíbel eliminar {objName}",
    "A valid group name must be provided" : "Debe fornecer un nome de grupo",
    "deleted {groupName}" : "{groupName} foi eliminado",
    "undo" : "desfacer",
    "never" : "nunca",
    "deleted {userName}" : "{userName} foi eliminado",
    "add group" : "engadir un grupo",
    "enabled" : "activado",
    "disabled" : "desactivado",
    "no group" : "sen grupo",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Cambiar o contrasinal provocará unha perda de datos, xa que a recuperación de datos non está dispoñíbel para este usuario",
    "A valid username must be provided" : "Debe fornecer un nome de usuario",
    "A valid password must be provided" : "Debe fornecer un contrasinal",
    "A valid email must be provided" : "Ten que fornecer un correo funcional",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Ola,<br><br>Só facerlle saber que dispón da conta %s.<br><br>O seu nome de usuario: %s<br>Para acceder a ela: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "Saúdos!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Ola,\n\nSó facerlle saber que dispón da conta %s.\n\nO seu nome de usuario: %s\nPara acceder a ela: %s\n",
    "User documentation" : "Documentación do usuario",
    "Administrator documentation" : "Documentación do administrador",
    "Online documentation" : "Documentación en liña",
    "Forum" : "Foro",
    "Issue tracker" : "Seguimento de incidencias",
    "Commercial support" : "Asistencia comercial",
    "Developer documentation" : "Documentación do desenvolvedor",
    "Documentation:" : "Documentación:",
    "Admin documentation" : "Documentación do administrador",
    "Show description …" : "Amosar a descrición ...",
    "Hide description …" : "Agochar a descrición ...",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Non é posíbel instalar esta aplicación por mor de non cumprirse as dependencias:",
    "Enable only for specific groups" : "Activar só para grupos específicos",
    "Uninstall App" : "Desinstalar unha aplicación",
    "Cron" : "Cron",
    "Last cron job execution: %s." : "Última execución da tarefa de cron: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Última execución da tarefa de cron: %s. Semella que algo vai mal",
    "Cron was not executed yet!" : "«Cron» aínda non foi executado!",
    "Open documentation" : "Abrir a documentación",
    "Execute one task with each page loaded" : "Executar unha tarefa con cada páxina cargada",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php está rexistrado nun servizo de WebCron para chamar a cron.php cada 15 minutos a través de HTTP.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Use o servizo «cron» do sistema para chamar ao ficheiro cron.php cada 15 minutos.",
    "Common Name" : "Nome común",
    "Valid until" : "Válido ata",
    "Issued By" : "Fornecido por",
    "Valid until %s" : "Válido ata %s",
    "Import root certificate" : "Importar o certificado raíz",
    "Server-side encryption" : "Cifrado na parte do servidor",
    "Enable server-side encryption" : "Activar o cifrado na parte do servidor",
    "Enable encryption" : "Activar o cifrado",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Non hai cargado ningún módulo de cifrado, active un módulo de cifrado no menú de aplicacións.",
    "Select default encryption module:" : "Seleccionar o módulo predeterminado de cifrado:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "É necesario migrar as súas chaves de cifrado do antigo cifrado (ownCloud <= 8,0) cara ao novo. Active o «Módulo predeterminado de cifrado» e execute «occ encryption:migrate»",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "É necesario migrar as chaves de cifrado do antigo cifrado (ownCloud <= 8,0) cara ao novo.",
    "Start migration" : "Iniciar a migración",
    "Sharing" : "Compartindo",
    "Allow apps to use the Share API" : "Permitir que as aplicacións empreguen o API para compartir",
    "Allow users to share via link" : "Permitir que os usuarios compartan a través de ligazóns",
    "Allow public uploads" : "Permitir os envíos públicos",
    "Enforce password protection" : "Forzar a protección por contrasinal",
    "Set default expiration date" : "Definir a data predeterminada de caducidade",
    "Allow users to send mail notification for shared files" : "Permitirlle aos usuarios enviar notificacións por correo para os ficheiros compartidos",
    "Expire after " : "Caduca após",
    "days" : "días",
    "Enforce expiration date" : "Obrigar a data de caducidade",
    "Allow resharing" : "Permitir compartir",
    "Restrict users to only share with users in their groups" : "Restrinxir aos usuarios a compartir só cos usuarios dos seus grupos",
    "Allow users to send mail notification for shared files to other users" : "Permitirlle aos usuarios enviar notificacións por correo a outros usuarios para notificarlles os ficheiros compartidos",
    "Exclude groups from sharing" : "Excluír grupos da compartición",
    "These groups will still be able to receive shares, but not to initiate them." : "Estes grupos poderán recibir comparticións, mais non inicialas.",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Todo (incidencias críticas, erros, avisos, información, depuración)",
    "Info, warnings, errors and fatal issues" : "Información, avisos, erros e incidencias críticas",
    "Warnings, errors and fatal issues" : "Avisos, erros e incidencias críticas",
    "Errors and fatal issues" : "Erros e incidencias críticas",
    "Fatal issues only" : "Só incidencias críticas",
    "Log" : "Rexistro",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "O ficheiro de rexistro é maior de 100 MB. Pódelle levar un anaco descargalo!",
    "None" : "Ningún",
    "Login" : "Acceso",
    "Plain" : "Simple",
    "NT LAN Manager" : "Xestor NT LAN",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Servidor de correo",
    "This is used for sending out notifications." : "Isto utilizase para o envío de notificacións.",
    "Send mode" : "Modo de envío",
    "Encryption" : "Cifrado",
    "From address" : "Desde o enderezo",
    "mail" : "correo",
    "Authentication method" : "Método de autenticación",
    "Authentication required" : "Requírese autenticación",
    "Server address" : "Enderezo do servidor",
    "Port" : "Porto",
    "Credentials" : "Credenciais",
    "SMTP Username" : "Nome de usuario SMTP",
    "SMTP Password" : "Contrasinal SMTP",
    "Store credentials" : "Gardar as credenciais",
    "Test email settings" : "Correo de proba dos axustes",
    "Send email" : "Enviar o correo",
    "Security & setup warnings" : "Avisos de seguridade e configuración",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Semella que PHP non está configurado correctamente para consultar as variábeis de entorno do sistema. A proba con getenv(\"PATH\") só devolve unha resposta baleira.",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Foi activada a restrición da configuración a só lectura. Isto impide o estabelecemento dalgunhas configuracións a través da interface web. Ademais, ten que facer escribíbel manualmente o ficheiro para cada actualización.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "Parece que PHP foi configuración para substituír bloques de documentos en liña. Isto fará que varias aplicacións sexan inaccesíbeis.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isto probabelmente se debe unha caché/acelerador como Zend OPcache ou eAccelerator.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Non se atopou o módulo de PHP «fileinfo». É recomendábel activar este módulo para obter os mellores resultados coa detección do tipo MIME.",
    "System locale can not be set to a one which supports UTF-8." : "Non é posíbel estabelecer a configuración rexional do sistema a unha que admita UTF-8.",
    "This means that there might be problems with certain characters in file names." : "Isto significa que pode haber problemas con certos caracteres en nomes de ficheiro.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Recomendámoslle que instale no sistema os paquetes necesarios para admitir unha das seguintes configuracións rexionais: %s.",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Se a instalación no está feita na raíz do dominio e usa o sistema cron, pode haber incidencias coa xeración de URL. Para evitar estes problemas, axuste a opción «overwrite.cli.url» no seu ficheiro config.php á ruta webroot da instalación (suxestión: «%s»)",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "Empregase SQLite como base de datos. Para instalacións grandes recomendámoslle que cambie a unha infraestrutura de base de datos diferente.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Concretamente, se emprega o cliente de escritorio para sincronización, desaconsellámoslle o uso de SQLite",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Non foi posíbel executar a tarefa de cron programada desde a liña de ordes. Atopáronse os seguintes erros técnicos:",
    "Tips & tricks" : "Trucos e consellos",
    "How to do backups" : "Como facer copias de seguridade",
    "Advanced monitoring" : "Supervisión avanzada",
    "Performance tuning" : "Afinación do rendemento",
    "Improving the config.php" : "Mellorando o config.php",
    "Theming" : "Tematización",
    "Hardening and security guidance" : "Orientacións sobre fortificación e seguridade",
    "Get the apps to sync your files" : "Obteña as aplicacións para sincronizar os seus ficheiros",
    "Desktop client" : "Cliente de escritorio",
    "Android app" : "Aplicación Android",
    "iOS app" : "Aplicación iOS",
    "Show First Run Wizard again" : "Amosar o axudante da primeira execución outra vez",
    "Profile picture" : "Imaxe do perfil",
    "Upload new" : "Novo envío",
    "Remove image" : "Retirar a imaxe",
    "Cancel" : "Cancelar",
    "Full name" : "Nome completo",
    "No display name set" : "Sen nome visíbel estabelecido",
    "Email" : "Correo",
    "Your email address" : "O seu enderezo de correo",
    "No email address set" : "Non hai un enderezo de correo definido",
    "You are member of the following groups:" : "Vostede é membro dos seguintes grupos:",
    "Password" : "Contrasinal",
    "Unable to change your password" : "Non é posíbel cambiar o seu contrasinal",
    "Current password" : "Contrasinal actual",
    "New password" : "Novo contrasinal",
    "Change password" : "Cambiar o contrasinal",
    "Language" : "Idioma",
    "Help translate" : "Axude na tradución",
    "Unlimited" : "Sen límites",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Desenvolvido pola {communityopen}comunidade ownCloud{linkclose}, o {githubopen}código fonte{linkclose} está licenciado baixo a {licenseopen}<abbr title=\"Licencia Pública Xeral Affero\">AGPL</abbr>{linkclose}.",
    "Name" : "Nome",
    "Username" : "Nome de usuario",
    "Done" : "Feito",
    "Version" : "Versión",
    "Personal" : "Persoal",
    "Admin" : "Administración",
    "Error" : "Erro",
    "Show storage location" : "Amosar a localización do almacenamento",
    "Show last log in" : "Amosar a última conexión",
    "Show user backend" : "Amosar a infraestrutura do usuario",
    "Send email to new user" : "Enviar correo ao novo usuario",
    "Show email address" : "Amosar o enderezo de correo",
    "E-Mail" : "Correo-e",
    "Create" : "Crear",
    "Admin Recovery Password" : "Contrasinal de recuperación do administrador",
    "Enter the recovery password in order to recover the users files during password change" : "Introduza o contrasinal de recuperación para recuperar os ficheiros dos usuarios durante o cambio de contrasinal",
    "Add Group" : "Engadir un grupo",
    "Group" : "Grupo",
    "Everyone" : "Todos",
    "Admins" : "Administradores",
    "Default Quota" : "Cota por omisión",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Introduza a cota de almacenamento (p.ex. «512 MB» ou «12 GB»)",
    "Other" : "Outro",
    "Full Name" : "Nome completo",
    "Group Admin for" : "Grupo de Admin para",
    "Quota" : "Cota",
    "Storage Location" : "Localización do almacenamento",
    "User Backend" : "Infraestrutura do usuario",
    "Last Login" : "Último acceso",
    "change full name" : "Cambiar o nome completo",
    "set new password" : "estabelecer un novo contrasinal",
    "change email address" : "cambiar o enderezo de correo",
    "Default" : "Predeterminado"
},
"nplurals=2; plural=(n != 1);");
